@@ -1,13 +1,13 @@
 
 import React, {
   PropTypes,
-  Component,
 } from 'react'
 import {
   View,
   requireNativeComponent,
   Platform,
 } from 'react-native'
+import PropTypes from 'prop-types';
 
 export default class AndroidSwipeRefreshLayout extends Component {
 
